@@ -93,7 +93,7 @@ def parseMarkdownFiles(md_dir_name):
                 exit(0)
             else:
                 with open(file_path,'r',encoding='utf-8') as f:
-                    markdown_htmls[file_path] = MarkdownParser.parse(f.read())
+                    markdown_htmls[file_path] = MarkdownParser.parse_withtag(f.read())
                 file_names.append(file_name)
         directory_tree.append({dir_name:file_names})
         
@@ -119,7 +119,8 @@ def parseConfig(config,markdown_htmls):
     index_src = '../../../css/index.css'
 
     css_scope = ''
-    css_scope += f"<link rel='stylesheet' href={prism_src} />"
+    if config['options']['enable_highlight']:
+        css_scope += f"<link rel='stylesheet' href={prism_src} />"
     css_scope += f"<link rel='stylesheet' href={index_src} />"
     basic_html_template = basic_html_template.replace('css-scope',css_scope)
     
@@ -128,6 +129,7 @@ def parseConfig(config,markdown_htmls):
     favicon_url = config['favicon']
     if favicon_url[:4] == 'http':
         basic_html_template = basic_html_template.replace('<%favicon%>',favicon_url)
+        
     else:
         img_name = favicon_url.split(os.sep)[-1]
         shutil.copy(favicon_url,f'./{html_dir_name}/img/'+img_name)
@@ -162,6 +164,11 @@ def zoodJSOptions(config,markdown_htmls):
     html_dir_name = config['html_folder']
     md_dir_name = config['markdown_folder']
 
+    if config['options']['enable_next_front']:
+        js_code = insertJScode('enable_next_front',html_dir_name)
+        js_code += f"<script>addLink(<%front_url%>,<%next_url%>,<%control%>)</script>"
+        js_scope += js_code
+
     if config['options']['enable_change_mode']:
     
         js_code = insertJScode('enable_change_mode',html_dir_name)
@@ -174,6 +181,11 @@ def zoodJSOptions(config,markdown_htmls):
         js_code += f"<script>addCodeCopy(\"../../../img/before_copy.png\",\"../../../img/after_copy.png\")</script>"
         js_scope += js_code
         
+    if config['options']['enable_navigator']:
+        js_code = insertJScode('enable_navigator',html_dir_name)
+        js_scope += js_code
+
+
     if config['options']['enable_highlight']:
         # 复制prismjs
         shutil.copy(os.path.join(os.path.dirname(__file__),'config','js','prismjs','prism.css'),f'{html_dir_name}/css')
@@ -182,11 +194,7 @@ def zoodJSOptions(config,markdown_htmls):
         highlight = f"<script type=\"text/javascript\" src=\"{src}\"></script>"
         js_scope += highlight
         
-    if config['options']['enable_next_front']:
-        js_code = insertJScode('enable_next_front',html_dir_name)
-        js_code += f"<script>addLink(<%front_url%>,<%next_url%>,<%control%>)</script>"
-        js_scope += js_code
-        
+
     if config['options']['enable_picture_title']:
         js_code = insertJScode('enable_picture_title',html_dir_name)
         js_scope += js_code
@@ -201,6 +209,18 @@ def zoodJSOptions(config,markdown_htmls):
         js_code += f"<script>addSearchBar({all_api_text},\"../../../img/search.svg\",\"../../../img/enter.svg\",\"Ctrl+K\")</script>"
         js_scope += js_code
 
+    if config['options']['enable_mermaid']:
+        js_code = '<script type=\"module\">\
+const codeBlocks = document.querySelectorAll(\'.language-mermaid\');\
+codeBlocks.forEach(codeBlock => {\
+    codeBlock.classList.remove(\'language-mermaid\');\
+    codeBlock.classList.add(\'mermaid\');\
+});\
+import mermaid from \'https://cdn.jsdelivr.net/npm/mermaid@10/dist/mermaid.esm.min.mjs\';\
+mermaid.initialize({ startOnLoad: true });\
+</script>'
+        js_scope += js_code
+
     js_scope += insertJScode('enable_check_box',html_dir_name)
 
     return js_scope
